@@ -119,7 +119,7 @@ More example put expressions:
   Regex-replacement:
     '$name = sub($name, "http.*com"i, "")'
   Regex-capture:
-    'if ($a =~ "([a-z]+)_([0-9]+)) { $b = "left_\1"; $c = "right_\2" }'
+	'if ($a =~ "([a-z]+)_([0-9]+)") { $b = "left_\1"; $c = "right_\2" }'
   Built-in variables:
     '$filename = FILENAME'
   Aggregations (use mlr put -q):
