@@ -44,9 +44,10 @@ func transformerStats2Usage(
 	fmt.Fprintf(o, "               There must be an even number of names.\n")
 	fmt.Fprintf(o, "-g {e,f,g}     Optional group-by-field names.\n")
 	fmt.Fprintf(o, "-v             Print additional output for linreg-pca.\n")
-	fmt.Fprintf(o, "-s             Print iterative stats. Useful in tail -f contexts (in which\n")
+	fmt.Fprintf(o, "-s             Print iterative stats. Useful in tail -f contexts, in which\n")
 	fmt.Fprintf(o, "               case please avoid pprint-format output since end of input\n")
-	fmt.Fprintf(o, "               stream will never be seen).\n")
+	fmt.Fprintf(o, "               stream will never be seen. Likewise, if input is coming from\n")
+	fmt.Fprintf(o, "               `tail -f`, be sure to use `--records-per-batch 1`.\n")
 	fmt.Fprintf(o, "--fit          Rather than printing regression parameters, applies them to\n")
 	fmt.Fprintf(o, "               the input data to compute new fit fields. All input records are\n")
 	fmt.Fprintf(o, "               held in memory until end of input stream. Has effect only for\n")
